@@ -12,7 +12,7 @@ The defaults are used in this module and across the Bright Edge eServices
 echo system.
 '''
 from .beearchiver import *
-from .beemsg import *
+# from .beemsg import *
 from .beescript import *
 from .beeutils import *
 from .beevenv import *
